==> aidlab_sdk-0.0.21.tar.gz: lib/src/api/aidlab_synchronization_delegate.dart <==
import 'activity_type.dart';
import 'aidlab.dart';
import 'sync_state.dart';
import 'body_position.dart';

abstract class AidlabSynchronizationDelegate {
  void syncStateDidChange(Aidlab aidlab, SyncState state);

  void didReceivePastECG(Aidlab aidlab, int timestamp, List<double> values);

  void didReceivePastRespiration(
      Aidlab aidlab, int timestamp, List<double> values);

  void didReceivePastSkinTemperature(
      Aidlab aidlab, int timestamp, double value);

  void didReceivePastHeartRate(Aidlab aidlab, int timestamp, int heartRate);

  void didReceivePastRr(Aidlab aidlab, int timestamp, int rr);

  void didReceiveUnsynchronizedSize(Aidlab aidlab, int unsynchronizedSize, double syncBytesPerSecond);

  void didReceivePastRespirationRate(Aidlab aidlab, int timestamp, int value);

  void didReceivePastActivity(
      Aidlab aidlab, int timestamp, ActivityType activity);

  void didReceivePastSteps(Aidlab aidlab, int timestamp, int value);

  void didReceivePastSoundVolume(Aidlab aidlab, int timestamp, int soundVolume);

  void didReceivePastAccelerometer(
      Aidlab aidlab, int timestamp, double ax, double ay, double az);

  void didReceivePastGyroscope(
      Aidlab aidlab, int timestamp, double qx, double qy, double qz);

  void didReceivePastMagnetometer(
      Aidlab aidlab, int timestamp, double mx, double my, double mz);

  void didReceivePastQuaternion(
      Aidlab aidlab, int timestamp, double qw, double qx, double qy, double qz);

  void didReceivePastOrientation(
      Aidlab aidlab, int timestamp, double roll, double pitch, double yaw);

  void didReceivePastBodyPosition(
      Aidlab aidlab, int timestamp, BodyPosition bodyPosition);

  void didReceivePastPressure(Aidlab aidlab, int timestamp, List<int> values);

  void didReceivePastSoundFeatures(Aidlab aidlab, List<double> values);

  void didDetectPastUserEvent(Aidlab aidlab, int timestamp);

  void didReceivePastSignalQuality(Aidlab aidlab, int timestamp, int value);
}

==> aidlab_sdk-0.2.0.tar.gz: lib/src/api/aidlab_synchronization_delegate.dart <==
import 'activity_type.dart';
import 'aidlab.dart';
import 'sync_state.dart';
import 'body_position.dart';

abstract class AidlabSynchronizationDelegate {
  void syncStateDidChange(Aidlab aidlab, SyncState state);

  void didReceivePastECG(Aidlab aidlab, int timestamp, List<double> values);

  void didReceivePastRespiration(
      Aidlab aidlab, int timestamp, List<double> values);

  void didReceivePastSkinTemperature(
      Aidlab aidlab, int timestamp, double value);

  void didReceivePastHeartRate(Aidlab aidlab, int timestamp, int heartRate);

  void didReceivePastRr(Aidlab aidlab, int timestamp, int rr);

  void didReceiveUnsynchronizedSize(
      Aidlab aidlab, int unsynchronizedSize, double syncBytesPerSecond);

  void didReceivePastRespirationRate(Aidlab aidlab, int timestamp, int value);

  void didReceivePastActivity(
      Aidlab aidlab, int timestamp, ActivityType activity);

  void didReceivePastSteps(Aidlab aidlab, int timestamp, int value);

  void didReceivePastSoundVolume(Aidlab aidlab, int timestamp, int soundVolume);

  void didReceivePastAccelerometer(
      Aidlab aidlab, int timestamp, double ax, double ay, double az);

  void didReceivePastGyroscope(
      Aidlab aidlab, int timestamp, double qx, double qy, double qz);

  void didReceivePastMagnetometer(
      Aidlab aidlab, int timestamp, double mx, double my, double mz);

  void didReceivePastQuaternion(
      Aidlab aidlab, int timestamp, double qw, double qx, double qy, double qz);

  void didReceivePastOrientation(
      Aidlab aidlab, int timestamp, double roll, double pitch, double yaw);

  void didReceivePastBodyPosition(
      Aidlab aidlab, int timestamp, BodyPosition bodyPosition);

  void didReceivePastPressure(Aidlab aidlab, int timestamp, List<int> values);

  void didReceivePastSoundFeatures(Aidlab aidlab, List<double> values);

  void didDetectPastUserEvent(Aidlab aidlab, int timestamp);

  void didReceivePastSignalQuality(Aidlab aidlab, int timestamp, int value);
}
